@@ -278,7 +278,15 @@ sub _parse_sync_data {
             elsif($e->{MsgType} == 10002){#撤回消息
                 $msg->{format} = "revoke";
             }
-            elsif($e->{MsgType} == 49) {#应用分享
+            elsif($e->{MsgType} == 49 and $e->{AppMsgType} == 6) {#文件分享
+                $msg->{format} = "media";
+                $msg->{media_type} = "file";
+                $msg->{media_code} = $e->{AppMsgType};
+                $msg->{media_id} = $e->{MediaId} . ":" . $e->{AppMsgType};
+                $msg->{media_name} = $e->{FileName};
+                $msg->{media_size} = $e->{FileSize};
+            }
+            elsif($e->{MsgType} == 49 and $e->{AppMsgType} == 5) {#应用分享
                 $msg->{format} = "app";
                 $msg->{app_title} = $e->{FileName};
                 $msg->{app_url}   = $e->{Url};
@@ -351,6 +359,7 @@ sub _parse_sync_data {
                 $msg->{content} = '[视频]' if $msg->{media_type} eq "video";
                 $msg->{content} = '[小视频]' if $msg->{media_type} eq "microvideo";
                 $msg->{content} = '[表情]' if $msg->{media_type} eq "emoticon";
+                $msg->{content} = '[文件]' if $msg->{media_type} eq "file";
             }
             elsif(defined $msg->{content}){
                 eval{$msg->{content} = Mojo::Util::html_unescape($msg->{content});};
